import sys
import os
sys.path.insert(0, os.path.abspath(os.path.join(os.path.dirname(__file__), '..')))

BASE_DIR = os.path.dirname(os.path.abspath(__file__))

list_files = [
    os.path.join(BASE_DIR, "random.hpp"),
    os.path.join(BASE_DIR, "libcurl-x64.dll")
]

from Osmia.email_message import EmailMessage
from Osmia.email_config import EmailConfig

# Configuration de l'email
config = EmailConfig(
    smtp_server="smtp.gmail.com", # server smtp
    smtp_port=587, # port smtp
    login="email_envoyeur@gmail.com", # email de l'envoyeur 
    password="mot de passe d'application" # password d'application
)

# Création du mail
email = EmailMessage(
    config.smtp_server,
    config.smtp_port,
    config.login,
    config.password
)

html_message = """
<html>
    <body>
        <h1 style="color:blue;">Ceci est un test HTML !</h1>
        <p>Envoi d'un email en <b>HTML</b> avec une pièce jointe.</p>
    </body>
</html>
"""

text_message = "Ceci est un test."

format_mail = ["plain", "html"]

# envoie le même email à tout les email de la list to_email
responses = email.send_email(
    to_email=["destinatere@gmail.com", "destinatere2@gmail.com", "destinatere3@gmail.com"], # email du destinataire ou faire une list d'email de destinataire
    subject="Test Email",
    message=html_message, 
    type_email=str(format_mail[1]), # html => pour envoyer sous format html, plain => sous format text
    list_files=list_files # 1 ou plusieur fichier cela fonctionne
)

# peut garder cette syntax 
response = email.send_email(
    to_email="destinatere@gmail.com", # email du destinataire ou faire une list d'email de destinataire
    subject="Test Email",
    message=html_message, 
    type_email=str(format_mail[1]), # html => pour envoyer sous format html, plain => sous format text
    list_files=list_files # 1 ou plusieur fichier cela fonctionne
)



import mimetypes
from email.mime.base import MIMEBase
from email import encoders

class EmailAttachment:
    def __init__(self, file_path):
        self.file_path = file_path

    def attach_file(self, msg):
        mimetype, _ = mimetypes.guess_type(self.file_path)
        if mimetype is None:
            raise ValueError("Error MimTypes not found")

        mime_main, mime_sub = mimetype.split("/")
        with open(self.file_path, "rb") as attachment:
            part = MIMEBase(mime_main, mime_sub)
            part.set_payload(attachment.read())

        encoders.encode_base64(part)
        part.add_header("Content-Disposition", f"attachment; filename={self.file_path}")
        msg.attach(part)



from .base_email import BaseEmail
from .email_attachment import EmailAttachment
from email.mime.text import MIMEText
from email.mime.multipart import MIMEMultipart

class EmailMessage:
    def __init__(self, smtp_server, smtp_port, login, password):
        self.base_email = BaseEmail(smtp_server, smtp_port, login, password)

    def create_message(self, to_email, subject, message, type_email="plain"):
        msg = MIMEMultipart()
        msg["From"] = self.base_email.login
        msg["To"] = to_email
        msg["Subject"] = subject
        msg.attach(MIMEText(message, type_email))
        return msg

    def add_attachments(self, msg, list_files):
        for file in list_files:
            attachment = EmailAttachment(file)
            attachment.attach_file(msg)
        return msg

    def send_email(self, to_email, subject, message, type_email="plain", list_files=[]):
        if isinstance(to_email, str):
            msg = self.create_message(to_email, subject, message, type_email)
            if list_files:
                msg = self.add_attachments(msg, list_files)
            return self.base_email.send(to_email, msg)
        
        elif isinstance(to_email, list):
            results = []
            for email in to_email:
                msg = self.create_message(email, subject, message, type_email)
                if list_files:
                    msg = self.add_attachments(msg, list_files)
                result = self.base_email.send(email, msg)
                results.append((email, result))
            return results
        else:
            return False